[libmessage-passing-zeromq-perl] 34/78: Rename dist
Jonas Smedegaard
js at alioth.debian.org
Mon Sep 30 09:28:22 UTC 2013
This is an automated email from the git hooks/post-receive script.
js pushed a commit to branch master
in repository libmessage-passing-zeromq-perl.
commit 6792b1e625c37f98bbff88ab31de73d02202f570
Author: Tomas Doran <bobtfish at bobtfish.net>
Date: Sat May 26 15:30:07 2012 +0100
Rename dist
---
Changes | 2 +
Makefile.PL | 6 +-
README | 92 +++++++++++++++++---
lib/{Log/Stash => Message/Passing}/Input/ZeroMQ.pm | 16 ++--
.../Stash => Message/Passing}/Output/ZeroMQ.pm | 26 +++---
lib/{Log/Stash => Message/Passing}/ZeroMQ.pm | 32 +++----
.../Passing}/ZeroMQ/Role/HasAContext.pm | 12 +--
.../Passing}/ZeroMQ/Role/HasASocket.pm | 8 +-
t/00_compile.t | 6 +-
t/author/podcoverage.t | 2 +-
t/input.t | 8 +-
t/output.t | 16 ++--
t/pushpull.t | 12 +--
13 files changed, 152 insertions(+), 86 deletions(-)
diff --git a/Changes b/Changes
index cc7dffd..86d6409 100644
--- a/Changes
+++ b/Changes
@@ -1,3 +1,5 @@
+ - Rename dist
+
0.002
- Avoid bug in earlier ZeroMQ versions by dependening on newer ones.
diff --git a/Makefile.PL b/Makefile.PL
index 43fe016..c7b9ccb 100644
--- a/Makefile.PL
+++ b/Makefile.PL
@@ -5,7 +5,7 @@ use Module::Install::AuthorRequires;
use Module::Install::AuthorTests;
use Module::Install::Authority;
-all_from 'lib/Log/Stash/ZeroMQ.pm';
+all_from 'lib/Message/Passing/ZeroMQ.pm';
license 'AGPL_3';
authority 'GHENRY';
@@ -18,7 +18,7 @@ requires 'JSON';
requires 'JSON::XS';
requires 'Try::Tiny';
requires 'Task::Weaken';
-requires 'Log::Stash' => '0.002';
+requires 'Message::Passing' => '0.002';
requires 'POSIX::AtFork' => '0.02';
requires 'Sub::Name';
@@ -34,7 +34,7 @@ author_requires 'Test::Spelling';
author_tests 't/author';
if ($Module::Install::AUTHOR) {
- system("pod2text lib/Log/Stash/ZeroMQ.pm > README")
+ system("pod2text lib/Message/Passing/ZeroMQ.pm > README")
and die $!;
}
diff --git a/README b/README
index c4eca7c..0af5650 100644
--- a/README
+++ b/README
@@ -1,5 +1,5 @@
NAME
- Log::Stash::ZeroMQ - input and output logstash messages to ZeroMQ.
+ Message::Passing::ZeroMQ - input and output logstash messages to ZeroMQ.
SYNOPSIS
# Terminal 1:
@@ -11,18 +11,18 @@ SYNOPSIS
{"data":{"some":"data"},"@metadata":"value"}
DESCRIPTION
- A ZeroMQ transport for Log::Stash.
+ A ZeroMQ transport for Message::Passing.
Designed for use as a log transport and aggregation mechanism for perl
applications, allowing you to aggregate structured and non-structured
log messages across the network in a non-blocking manor.
- Clients (I.e. users of the Log::Stash::Output::ZeroMQ class) connect to
- a server (I.e. a user of the Log::Stash::Input::ZeroMQ class) via
- ZeroMQ's pub/sub sockets. These are setup to be lossy and non-blocking,
- meaning that if the log-receiver process is down or slow, then the
- application will queue a small (and configurable) amount of logs on it's
- side, and after that log messages will be dropped.
+ Clients (I.e. users of the Message::Passing::Output::ZeroMQ class)
+ connect to a server (I.e. a user of the Message::Passing::Input::ZeroMQ
+ class) via ZeroMQ's pub/sub sockets. These are setup to be lossy and
+ non-blocking, meaning that if the log-receiver process is down or slow,
+ then the application will queue a small (and configurable) amount of
+ logs on it's side, and after that log messages will be dropped.
Whilst throwing away log messages isn't a good thing to do, or something
that you want to happen regularly, in many (especially web application)
@@ -36,19 +36,83 @@ DESCRIPTION
HOW TO USE
In your application emitting messages, you can either use
- Log::Stash::Output::ZeroMQ directly, of you can use it via
- Log::Dispatch::Log::Stash.
+ Message::Passing::Output::ZeroMQ directly, of you can use it via
+ Log::Dispatch::Message::Passing.
# FIXME - Example code, including overriding IP to connect to here
On your log aggregation server, just run the logstash utility:
- # FIXME - Example command line here
+ logstash --input ZeroMQ --input_options '{"socket_bind":"tcp://*:5222"}' \
+ --output File --output_options '{"filename":"/tmp/my_test.log"}'
+
+CONNECTION DIRECTION
+ Note that in ZeroMQ, the connection direction and the direction of
+ message flow can be entirely opposite. I.e. a client can connect to a
+ server and send messages to it, or recieve messages from it (depending
+ on the direction of the socket types).
+
+SOCKET TYPES
+ ZeroMQ supports multiple socket types, the only ones used in
+ Message::Passing::ZeroMQ are:
+
+ PUB/SUB
+ Used for general message distribution - you can have either multiple
+ producers (PUB) which connect to one consumer (SUB), or multiple
+ consumers (SUB) which connect to one producer (PUB).
+
+ All consumers will get a copy of every message.
+
+ In Message::Passing terms, Message::Passing::Input::ZeroMQ is for SUB
+ sockets, and Message::Passing::Output::ZeroMQ is for PUB sockets.
+
+ PUSH/PULL
+ Used for message distribution. A sever (PUSH) distributes messages
+ between a number of connecting clients (PULL)
+
+ In Message::Passing terms, Message::Passing::Input::ZeroMQ is for PULL
+ sockets, and Message::Passing::Output::ZeroMQ is for PUSH sockets.
+
+MORE COMPLEX EXAMPLES
+ With this in mind, we can easily create a system which aggregates
+ messages from multiple publishers, and passes them out (in a round-robin
+ fashion) to a pool of workers.
+
+ # The message distributor:
+ logstash --input ZeroMQ --input_options '{"socket_bind":"tcp://*:5222"}' \
+ --output ZeroMQ --output_options '{"socket_bind":"tcp://*:5223","socket_type":"PUSH"}'
+
+ # Workers
+ {
+ package MyApp::MessageWorker;
+ use Moo;
+
+ with 'Message::Passing::Role::Filter';
+
+ sub filter {
+ my ($self, $message) = @_;
+ # .... process the message in any way you want here
+ return undef; # Do not output the message..
+ }
+ }
+
+ logstash --input ZeroMQ --input_options '{"connect":"tcp://127.0.0.1:5223","socket_type":"PULL"}'
+ --filter '+MyApp::MessageWorker'
+ --output STDOUT
+
+ You log messages into the distributor as per the above simple example,
+ and you can run multiple worker processes..
+
+ Less trivial setups could/would emit messages on error, or maybe re-emit
+ the incoming message after transforming it in some way.
SEE ALSO
- Log::Stash::Output::ZeroMQ
- Log::Stash::Input::ZeroMQ
- Log::Stash
+ For more detailed information about ZeroMQ and how it works, please
+ consult the ZeroMQ guide and the other links below:
+
+ Message::Passing::Output::ZeroMQ
+ Message::Passing::Input::ZeroMQ
+ Message::Passing
ZeroMQ
<http://www.zeromq.org/>
diff --git a/lib/Log/Stash/Input/ZeroMQ.pm b/lib/Message/Passing/Input/ZeroMQ.pm
similarity index 86%
rename from lib/Log/Stash/Input/ZeroMQ.pm
rename to lib/Message/Passing/Input/ZeroMQ.pm
index 8469df5..6221b26 100644
--- a/lib/Log/Stash/Input/ZeroMQ.pm
+++ b/lib/Message/Passing/Input/ZeroMQ.pm
@@ -1,4 +1,4 @@
-package Log::Stash::Input::ZeroMQ;
+package Message::Passing::Input::ZeroMQ;
use Moose;
use ZeroMQ qw/:all/;
use AnyEvent;
@@ -7,8 +7,8 @@ use Try::Tiny qw/ try catch /;
use namespace::autoclean;
with qw/
- Log::Stash::ZeroMQ::Role::HasASocket
- Log::Stash::Role::Input
+ Message::Passing::ZeroMQ::Role::HasASocket
+ Message::Passing::Role::Input
/;
has '+_socket' => (
@@ -74,7 +74,7 @@ sub BUILD {
=head1 NAME
-Log::Stash::Input::ZeroMQ - input logstash messages from ZeroMQ.
+Message::Passing::Input::ZeroMQ - input logstash messages from ZeroMQ.
=head1 DESCRIPTION
@@ -82,11 +82,11 @@ Log::Stash::Input::ZeroMQ - input logstash messages from ZeroMQ.
=over
-=item L<Log::Stash::ZeroMQ>
+=item L<Message::Passing::ZeroMQ>
-=item L<Log::Stash::Output::ZeroMQ>
+=item L<Message::Passing::Output::ZeroMQ>
-=item L<Log::Stash>
+=item L<Message::Passing>
=item L<ZeroMQ>
@@ -104,7 +104,7 @@ the SureVoIP API -
=head1 AUTHOR, COPYRIGHT AND LICENSE
-See L<Log::Stash::ZeroMQ>.
+See L<Message::Passing::ZeroMQ>.
=cut
diff --git a/lib/Log/Stash/ZeroMQ.pm b/lib/Message/Passing/ZeroMQ.pm
similarity index 80%
rename from lib/Log/Stash/ZeroMQ.pm
rename to lib/Message/Passing/ZeroMQ.pm
index 1c4d4e3..50c4e2c 100644
--- a/lib/Log/Stash/ZeroMQ.pm
+++ b/lib/Message/Passing/ZeroMQ.pm
@@ -1,4 +1,4 @@
-package Log::Stash::ZeroMQ;
+package Message::Passing::ZeroMQ;
use Moose ();
use ZeroMQ qw/ :all /;
use POSIX::AtFork ();
@@ -21,7 +21,7 @@ POSIX::AtFork->add_to_prepare(subname at_fork => sub {
=head1 NAME
-Log::Stash::ZeroMQ - input and output logstash messages to ZeroMQ.
+Message::Passing::ZeroMQ - input and output logstash messages to ZeroMQ.
=head1 SYNOPSIS
@@ -35,13 +35,13 @@ Log::Stash::ZeroMQ - input and output logstash messages to ZeroMQ.
=head1 DESCRIPTION
-A L<ZeroMQ> transport for L<Log::Stash>.
+A L<ZeroMQ> transport for L<Message::Passing>.
Designed for use as a log transport and aggregation mechanism for perl applications, allowing you
to aggregate structured and non-structured log messages across the network in a non-blocking manor.
-Clients (I.e. users of the L<Log::Stash::Output::ZeroMQ> class) connect to a server (I.e. a user of the
-L<Log::Stash::Input::ZeroMQ> class) via ZeroMQ's pub/sub sockets. These are setup to be lossy and non-blocking,
+Clients (I.e. users of the L<Message::Passing::Output::ZeroMQ> class) connect to a server (I.e. a user of the
+L<Message::Passing::Input::ZeroMQ> class) via ZeroMQ's pub/sub sockets. These are setup to be lossy and non-blocking,
meaning that if the log-receiver process is down or slow, then the application will queue a small (and configurable)
amount of logs on it's side, and after that log messages will be dropped.
@@ -54,8 +54,8 @@ server) is significantly less acceptable than the loss of non-essential logging
=head1 HOW TO USE
-In your application emitting messages, you can either use L<Log::Stash::Output::ZeroMQ> directly, of you can use
-it via L<Log::Dispatch::Log::Stash>.
+In your application emitting messages, you can either use L<Message::Passing::Output::ZeroMQ> directly, of you can use
+it via L<Log::Dispatch::Message::Passing>.
# FIXME - Example code, including overriding IP to connect to here
@@ -72,7 +72,7 @@ recieve messages from it (depending on the direction of the socket types).
=head1 SOCKET TYPES
-ZeroMQ supports multiple socket types, the only ones used in Log::Stash::ZeroMQ are:
+ZeroMQ supports multiple socket types, the only ones used in Message::Passing::ZeroMQ are:
=head2 PUB/SUB
@@ -82,16 +82,16 @@ producer (PUB).
All consumers will get a copy of every message.
-In Log::Stash terms, L<Log::Stash::Input::ZeroMQ> is for SUB sockets, and
-L<Log::Stash::Output::ZeroMQ> is for PUB sockets.
+In Message::Passing terms, L<Message::Passing::Input::ZeroMQ> is for SUB sockets, and
+L<Message::Passing::Output::ZeroMQ> is for PUB sockets.
=head2 PUSH/PULL
Used for message distribution. A sever (PUSH) distributes messages between
a number of connecting clients (PULL)
-In Log::Stash terms, L<Log::Stash::Input::ZeroMQ> is for PULL sockets, and
-L<Log::Stash::Output::ZeroMQ> is for PUSH sockets.
+In Message::Passing terms, L<Message::Passing::Input::ZeroMQ> is for PULL sockets, and
+L<Message::Passing::Output::ZeroMQ> is for PUSH sockets.
=head1 MORE COMPLEX EXAMPLES
@@ -107,7 +107,7 @@ multiple publishers, and passes them out (in a round-robin fashion) to a pool of
package MyApp::MessageWorker;
use Moo;
- with 'Log::Stash::Role::Filter';
+ with 'Message::Passing::Role::Filter';
sub filter {
my ($self, $message) = @_;
@@ -132,11 +132,11 @@ For more detailed information about ZeroMQ and how it works, please consult the
=over
-=item L<Log::Stash::Output::ZeroMQ>
+=item L<Message::Passing::Output::ZeroMQ>
-=item L<Log::Stash::Input::ZeroMQ>
+=item L<Message::Passing::Input::ZeroMQ>
-=item L<Log::Stash>
+=item L<Message::Passing>
=item L<ZeroMQ>
diff --git a/lib/Log/Stash/ZeroMQ/Role/HasAContext.pm b/lib/Message/Passing/ZeroMQ/Role/HasAContext.pm
similarity index 68%
rename from lib/Log/Stash/ZeroMQ/Role/HasAContext.pm
rename to lib/Message/Passing/ZeroMQ/Role/HasAContext.pm
index 2f9f38e..1fd1fd4 100644
--- a/lib/Log/Stash/ZeroMQ/Role/HasAContext.pm
+++ b/lib/Message/Passing/ZeroMQ/Role/HasAContext.pm
@@ -1,6 +1,6 @@
-package Log::Stash::ZeroMQ::Role::HasAContext;
+package Message::Passing::ZeroMQ::Role::HasAContext;
use Moose::Role;
-use Log::Stash::ZeroMQ ();
+use Message::Passing::ZeroMQ ();
use ZeroMQ ':all';
use Scalar::Util qw/ weaken /;
use namespace::autoclean;
@@ -14,8 +14,8 @@ has _ctx => (
default => sub {
my $self = shift;
my $ctx = ZeroMQ::Context->new();
- push(@Log::Stash::ZeroMQ::_WITH_CONTEXTS, $self);
- weaken($Log::Stash::ZeroMQ::_WITH_CONTEXTS[-1]);
+ push(@Message::Passing::ZeroMQ::_WITH_CONTEXTS, $self);
+ weaken($Message::Passing::ZeroMQ::_WITH_CONTEXTS[-1]);
$ctx;
},
clearer => '_clear_ctx',
@@ -25,7 +25,7 @@ has _ctx => (
=head1 NAME
-Log::Stash::ZeroMQ::Role::HasAContext - Components with a ZeroMQ context consume this role.
+Message::Passing::ZeroMQ::Role::HasAContext - Components with a ZeroMQ context consume this role.
=head1 SPONSORSHIP
@@ -37,7 +37,7 @@ the SureVoIP API -
=head1 AUTHOR, COPYRIGHT AND LICENSE
-See L<Log::Stash::ZeroMQ>.
+See L<Message::Passing::ZeroMQ>.
=cut
diff --git a/lib/Log/Stash/ZeroMQ/Role/HasASocket.pm b/lib/Message/Passing/ZeroMQ/Role/HasASocket.pm
similarity index 94%
rename from lib/Log/Stash/ZeroMQ/Role/HasASocket.pm
rename to lib/Message/Passing/ZeroMQ/Role/HasASocket.pm
index dcb7688..bfefc3a 100644
--- a/lib/Log/Stash/ZeroMQ/Role/HasASocket.pm
+++ b/lib/Message/Passing/ZeroMQ/Role/HasASocket.pm
@@ -1,10 +1,10 @@
-package Log::Stash::ZeroMQ::Role::HasASocket;
+package Message::Passing::ZeroMQ::Role::HasASocket;
use Moose::Role;
use ZeroMQ ':all';
use Moose::Util::TypeConstraints;
use namespace::autoclean;
-with 'Log::Stash::ZeroMQ::Role::HasAContext';
+with 'Message::Passing::ZeroMQ::Role::HasAContext';
has _socket => (
is => 'ro',
@@ -73,7 +73,7 @@ has connect => (
=head1 NAME
-Log::Stash::ZeroMQ::HasASocket - Role for instances which have a ZeroMQ socket.
+Message::Passing::ZeroMQ::HasASocket - Role for instances which have a ZeroMQ socket.
=head1 ATTRIBUTES
@@ -158,7 +158,7 @@ the SureVoIP API -
=head1 AUTHOR, COPYRIGHT AND LICENSE
-See L<Log::Stash::ZeroMQ>.
+See L<Message::Passing::ZeroMQ>.
=cut
diff --git a/t/00_compile.t b/t/00_compile.t
index 7386ee5..93c1897 100644
--- a/t/00_compile.t
+++ b/t/00_compile.t
@@ -3,9 +3,9 @@ use warnings;
use Test::More;
-use_ok('Log::Stash::ZeroMQ');
-use_ok('Log::Stash::Input::ZeroMQ');
-use_ok('Log::Stash::Output::ZeroMQ');
+use_ok('Message::Passing::ZeroMQ');
+use_ok('Message::Passing::Input::ZeroMQ');
+use_ok('Message::Passing::Output::ZeroMQ');
done_testing;
diff --git a/t/author/podcoverage.t b/t/author/podcoverage.t
index 4d703ed..70dacbe 100644
--- a/t/author/podcoverage.t
+++ b/t/author/podcoverage.t
@@ -8,7 +8,7 @@ use Test::Pod::Coverage 1.04;
my @modules = all_modules;
our @private = ( 'BUILD' );
foreach my $module (@modules) {
- local @private = (@private, 'expand_class_name', 'make') if $module =~ /^Log::Stash::DSL::Factory$/;
+ local @private = (@private, 'expand_class_name', 'make') if $module =~ /^Message::Passing::DSL::Factory$/;
pod_coverage_ok($module, {
also_private => \@private,
diff --git a/t/input.t b/t/input.t
index f758dee..928b153 100644
--- a/t/input.t
+++ b/t/input.t
@@ -3,15 +3,15 @@ use warnings;
use Test::More;
use AnyEvent;
-use Log::Stash::Input::ZeroMQ;
-use Log::Stash::Output::Test;
+use Message::Passing::Input::ZeroMQ;
+use Message::Passing::Output::Test;
use ZeroMQ qw/:all/;
my $cv = AnyEvent->condvar;
-my $output = Log::Stash::Output::Test->new(
+my $output = Message::Passing::Output::Test->new(
cb => sub { $cv->send },
);
-my $input = Log::Stash::Input::ZeroMQ->new(
+my $input = Message::Passing::Input::ZeroMQ->new(
socket_bind => 'tcp://*:5558',
output_to => $output,
);
diff --git a/t/output.t b/t/output.t
index df61c0e..15fc986 100644
--- a/t/output.t
+++ b/t/output.t
@@ -3,22 +3,22 @@ use warnings;
use Test::More;
use AnyEvent;
-use Log::Stash::Input::ZeroMQ;
-use Log::Stash::Output::Test;
-use Log::Stash::Output::ZeroMQ;
+use Message::Passing::Input::ZeroMQ;
+use Message::Passing::Output::Test;
+use Message::Passing::Output::ZeroMQ;
-my $output = Log::Stash::Output::ZeroMQ->new(
+my $output = Message::Passing::Output::ZeroMQ->new(
connect => 'tcp://127.0.0.1:5558',
);
$output->consume({foo => 'bar'});
-use Log::Stash::Input::ZeroMQ;
-use Log::Stash::Output::Test;
+use Message::Passing::Input::ZeroMQ;
+use Message::Passing::Output::Test;
my $cv = AnyEvent->condvar;
-my $input = Log::Stash::Input::ZeroMQ->new(
+my $input = Message::Passing::Input::ZeroMQ->new(
socket_bind => 'tcp://*:5558',
- output_to => Log::Stash::Output::Test->new(
+ output_to => Message::Passing::Output::Test->new(
cb => sub { $cv->send }
),
);
diff --git a/t/pushpull.t b/t/pushpull.t
index 3442a5b..c47e741 100644
--- a/t/pushpull.t
+++ b/t/pushpull.t
@@ -3,17 +3,17 @@ use warnings;
use Test::More;
-use Log::Stash::Input::ZeroMQ;
-use Log::Stash::Output::ZeroMQ;
-use Log::Stash::Output::Test;
-my $test = Log::Stash::Output::Test->new;
-my $input = Log::Stash::Input::ZeroMQ->new(
+use Message::Passing::Input::ZeroMQ;
+use Message::Passing::Output::ZeroMQ;
+use Message::Passing::Output::Test;
+my $test = Message::Passing::Output::Test->new;
+my $input = Message::Passing::Input::ZeroMQ->new(
connect => 'tcp://127.0.0.1:5558',
socket_type => 'PULL',
output_to => $test,
);
-my $output = Log::Stash::Output::ZeroMQ->new(
+my $output = Message::Passing::Output::ZeroMQ->new(
socket_bind => 'tcp://127.0.0.1:5558',
socket_type => 'PUSH',
);
diff --git a/lib/Log/Stash/Output/ZeroMQ.pm b/lib/Message/Passing/Output/ZeroMQ.pm
similarity index 69%
rename from lib/Log/Stash/Output/ZeroMQ.pm
rename to lib/Message/Passing/Output/ZeroMQ.pm
index df96724..4ced723 100644
--- a/lib/Log/Stash/Output/ZeroMQ.pm
+++ b/lib/Message/Passing/Output/ZeroMQ.pm
@@ -1,9 +1,9 @@
-package Log::Stash::Output::ZeroMQ;
+package Message::Passing::Output::ZeroMQ;
use Moose;
use ZeroMQ ':all';
use namespace::autoclean;
-with 'Log::Stash::ZeroMQ::Role::HasASocket';
+with 'Message::Passing::ZeroMQ::Role::HasASocket';
has '+_socket' => (
handles => {
@@ -25,25 +25,25 @@ sub consume {
$self->_zmq_send($bytes);
}
-with 'Log::Stash::Role::Output';
+with 'Message::Passing::Role::Output';
1;
=head1 NAME
-Log::Stash::Output::ZeroMQ - output logstash messages to ZeroMQ.
+Message::Passing::Output::ZeroMQ - output logstash messages to ZeroMQ.
=head1 SYNOPSIS
- use Log::Stash::Output::ZeroMQ;
+ use Message::Passing::Output::ZeroMQ;
- my $logger = Log::Stash::Output::ZeroMQ->new;
+ my $logger = Message::Passing::Output::ZeroMQ->new;
$logger->consume({data => { some => 'data'}, '@metadata' => 'value' });
# You are expected to produce a logstash message format compatible message,
# see the documentation in Log::Stash for more details.
# Or see Log::Dispatch::Log::Stash for a more 'normal' interface to
# simple logging.
# Or use directly on command line:
@@ -52,7 +52,7 @@ Log::Stash::Output::ZeroMQ - output logstash messages to ZeroMQ.
=head1 DESCRIPTION
-A L<Log::Stash> L<ZeroMQ> output class.
+A L<Message::Passing> L<ZeroMQ> output class.
Can be used as part of a chain of classes with the L<logstash> utility, or directly as
a logger in normal perl applications.
@@ -67,11 +67,11 @@ Sends a message.
=over
-=item L<Log::Stash::ZeroMQ>
+=item L<Message::Passing::ZeroMQ>
-=item L<Log::Stash::Input::ZeroMQ>
+=item L<Message::Passing::Input::ZeroMQ>
-=item L<Log::Stash>
+=item L<Message::Passing>
=item L<ZeroMQ>
@@ -89,7 +89,7 @@ the SureVoIP API -
=head1 AUTHOR, COPYRIGHT AND LICENSE
-See L<Log::Stash>.
+See L<Message::Passing>.
=cut
@@ -25,25 +25,25 @@ sub consume {
$logger->consume({data => { some => 'data'}, '@metadata' => 'value' });
# You are expected to produce a logstash message format compatible message,
- # see the documentation in Log::Stash for more details.
+ # see the documentation in Message::Passing for more details.
- # Or see Log::Dispatch::Log::Stash for a more 'normal' interface to
+ # Or see Log::Dispatch::Message::Passing for a more 'normal' interface to
# simple logging.
# Or use directly on command line:
--
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-perl/packages/libmessage-passing-zeromq-perl.git
More information about the Pkg-perl-cvs-commits
mailing list